==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebGridToolbarActionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridToolbarContentDescriptionMetadata } from "./WebGridToolbarContentDescriptionMetadata";
import { WebGridToolbarActionsDescription } from "./WebGridToolbarActionsDescription";
/**
 * @hidden
 */
export let WebGridToolbarActionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridToolbarActionsDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridToolbarActionsDescriptionMetadata.a == null) {
                WebGridToolbarActionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridToolbarActionsDescriptionMetadata.c(WebGridToolbarActionsDescriptionMetadata.a);
            }
            if (a.k(WebGridToolbarActionsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebGridToolbarActionsDescriptionMetadata.a);
        }
        static c(a) {
            WebGridToolbarContentDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:GridToolbarActions");
            a.item("__tagNameWC", "String:igc-grid-toolbar-actions");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("Actions", "Collection:WebGridToolbarBaseAction:WebGridToolbarBaseActionCollection:WebGridToolbarBaseAction");
            a.item("Name", "String");
        }
        static d(a) {
            WebGridToolbarActionsDescriptionMetadata.b(a);
            a.ad("WebGridToolbarActions", () => new WebGridToolbarActionsDescription());
            a.ac("WebGridToolbarActions", WebGridToolbarActionsDescriptionMetadata.a);
        }
    }
    WebGridToolbarActionsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridToolbarActionsDescriptionMetadata, 'WebGridToolbarActionsDescriptionMetadata');
    WebGridToolbarActionsDescriptionMetadata.a = null;
    return WebGridToolbarActionsDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/WebGridToolbarActionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridToolbarContentDescriptionMetadata } from "./WebGridToolbarContentDescriptionMetadata";
import { WebGridToolbarActionsDescription } from "./WebGridToolbarActionsDescription";
/**
 * @hidden
 */
export let WebGridToolbarActionsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridToolbarActionsDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridToolbarActionsDescriptionMetadata.a == null) {
                WebGridToolbarActionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridToolbarActionsDescriptionMetadata.c(WebGridToolbarActionsDescriptionMetadata.a);
            }
            if (a.k(WebGridToolbarActionsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebGridToolbarActionsDescriptionMetadata.a);
        }
        static c(a) {
            WebGridToolbarContentDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:GridToolbarActions");
            a.item("__tagNameWC", "String:igc-grid-toolbar-actions");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("Actions", "Collection:WebGridToolbarBaseAction:WebGridToolbarBaseActionCollection:WebGridToolbarBaseAction");
            a.item("Name", "String");
        }
        static d(a) {
            WebGridToolbarActionsDescriptionMetadata.b(a);
            a.ae("WebGridToolbarActions", () => new WebGridToolbarActionsDescription());
            a.ad("WebGridToolbarActions", WebGridToolbarActionsDescriptionMetadata.a);
        }
    }
    WebGridToolbarActionsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGridToolbarActionsDescriptionMetadata, 'WebGridToolbarActionsDescriptionMetadata');
    WebGridToolbarActionsDescriptionMetadata.a = null;
    return WebGridToolbarActionsDescriptionMetadata;
})();
